aboutsummaryrefslogtreecommitdiff
path: root/mod/blog/read.php
diff options
context:
space:
mode:
Diffstat (limited to 'mod/blog/read.php')
-rw-r--r--mod/blog/read.php123
1 files changed, 65 insertions, 58 deletions
diff --git a/mod/blog/read.php b/mod/blog/read.php
index 7be396759..291a7bdf8 100644
--- a/mod/blog/read.php
+++ b/mod/blog/read.php
@@ -1,59 +1,66 @@
-<?php
-
- /**
- * Elgg read blog post page
- *
- * @package ElggBlog
- * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
- * @author Curverider Ltd <info@elgg.com>
- * @copyright Curverider Ltd 2008-2010
- * @link http://elgg.com/
- */
-
- // Load Elgg engine
- require_once(dirname(dirname(dirname(__FILE__))) . "/engine/start.php");
-
- // Get the specified blog post
- $post = (int) get_input('blogpost');
-
- // If we can get out the blog post ...
- if ($blogpost = get_entity($post)) {
-
- // Get any comments
- //$comments = $blogpost->getAnnotations('comments');
-
- // Set the page owner
- if ($blogpost->container_guid) {
- set_page_owner($blogpost->container_guid);
- } else {
- set_page_owner($blogpost->owner_guid);
- }
-
- // Display it
- $area2 = elgg_view_entity($blogpost, true);
- /*$area2 = elgg_view("object/blog",array(
- 'entity' => $blogpost,
- 'entity_owner' => $page_owner,
- 'comments' => $comments,
- 'full' => true
- ));
- */
- // Set the title appropriately
- $title = sprintf(elgg_echo("blog:posttitle"),$page_owner->name,$blogpost->title);
-
- // Display through the correct canvas area
- $body = elgg_view_layout("two_column_left_sidebar", '', $area1 . $area2);
-
- // If we're not allowed to see the blog post
- } else {
-
- // Display the 'post not found' page instead
- $body = elgg_view("blog/notfound");
- $title = elgg_echo("blog:notfound");
-
- }
-
- // Display page
- page_draw($title,$body);
-
+<?php
+
+ /**
+ * Elgg read blog post page
+ * @package ElggBlog
+ * @copyright Curverider Ltd 2008-2009
+ */
+
+// Load Elgg engine
+require_once(dirname(dirname(dirname(__FILE__))) . "/engine/start.php");
+
+// Get the specified blog post
+$post = (int) get_input('blogpost');
+
+// If we can get out the blog post ...
+if ($blogpost = get_entity($post)) {
+ // Set variables
+ $blog_acl = '';
+ // Set the page owner
+ if ($blogpost->container_guid)
+ set_page_owner($blogpost->container_guid);
+ else
+ set_page_owner($blogpost->owner_guid);
+
+ //set breadcrumbs
+ //$area2 = elgg_view('elggcampus_layout/breadcrumbs', array('object_title' => $blogpost->title, 'object_type' => 'blog'));
+ // Display it
+ $area2 .= elgg_view_entity($blogpost, true);
+ //get the blog's access level
+ $blog_acl = get_readable_access_level($blogpost->access_id);
+ // Set the title appropriately
+ $title = $blogpost->title;
+ //set blog ownerblock if not your own
+ if($blogpost->owner_guid != get_loggedin_user()->guid){
+ $area3 = elgg_view('blog/ownerblock');
+ }
+ //display the read sidebar
+ //$area3 .= elgg_view('blog/read_sidebar', array('blog_acl' => $blog_acl, 'entity' => $blogpost));
+ //if the logged in user is not looking at their stuff, display the ownerblock otherwise
+ //show the users favourites
+ if(page_owner() != get_loggedin_user()->guid){
+ $area3 = elgg_view('blog/ownerblock');
+ }else{
+ //a view for the favourites plugin to extend
+ $area3 .= elgg_view("blogs/sidebar_options", array("object_type" => 'blog'));
+ }
+ //display archive
+ $area3 .= elgg_view("blog/archive");
+ //get the latest comments on user's blog posts
+ $comments = get_annotations(0, "object", "blog", "generic_comment", "", 0, 4, 0, "desc",0,0,page_owner());
+ $area3 .= elgg_view('page_elements/latest_comments', array('comments' => $comments));
+
+ // Display through the correct canvas area
+ $body = elgg_view_layout("one_column_with_sidebar", $area1.$area2, $area3);
+
+// If we're not allowed to see the blog post
+} else {
+ // Display the 'post not found' page instead
+ $body = elgg_view("blog/notfound");
+ $title = elgg_echo("blog:notfound");
+}
+
+// Display page
+page_draw($title,$body);
+
?> \ No newline at end of file